@@ -2,11 +2,11 @@ package Chicken::Ipsum;
 use strict;
 use warnings;
 
-our $VERSION = '0.0.1';
+our $VERSION = '0.0.2';
 
 =head1 NAME
 
-Chicken::Ipsum - Generate random chicken noises.
+Chicken::Ipsum - Generate random chicken noises
 
 =head1 SYNOPSIS
 
@@ -96,12 +96,7 @@ Returns INTEGER Chicken words.
 
 sub words {
     my ($self, $num) = @_;
-    my @words;
-    # Words remaining "goes to" 0, LOL.
-    # (See https://stackoverflow.com/q/1642028/237955)
-    while ($num --> 0) {
-        push @words, _get_word();
-    }
+    my @words = sample $num, @{+WORDS};
     return wantarray ? @words : "@words";
 }
 
@@ -114,6 +109,8 @@ Returns INTEGER sentences in Chicken.
 sub sentences {
     my ($self, $num) = @_;
     my @sentences;
+    # Sentences remaining "goes to" 0, LOL.
+    # (See https://stackoverflow.com/q/1642028/237955)
     while ($num --> 0) {
         push @sentences, $self->_get_sentence();
     }
@@ -153,10 +150,6 @@ sub _get_sentence {
     return $words . _get_punctuation();
 }
 
-sub _get_word {
-	return sample 1, @{+WORDS};
-}
-
 =head1 AUTHOR
 
 Dan Church (DCHURCH on CPAN)
